@@ -27,10 +27,9 @@ from __future__ import (
 
 from .bloch import (
     display_bloch_sphere,
-    display_bloch_sphere_qutrit,
-    display_two_qubit_visualization,
-    print_bloch_sphere_data,
-    print_bloch_sphere_data_qutrit,
+    display_bloch_sphere_from_bloch_vectors,
+    display_bloch_sphere_from_density_matrices,
+    display_bloch_spheres_and_correlations,
 )
 from .controls import (
     plot_controls,
@@ -44,11 +43,11 @@ from .discriminators import (
 from .filter_functions import plot_filter_functions
 from .style import get_qctrl_style
 
-# Note that, in the public version of this package, the Bloch sphere functions are simply stubs that
-# print error messages. With that in mind, we exclude those functions from __all__, indicating that
-# they should typically not be used by public users. A convenient side effect is that the functions
-# are excluded from the generated reference documentation.
 __all__ = [
+    "display_bloch_sphere",
+    "display_bloch_sphere_from_bloch_vectors",
+    "display_bloch_sphere_from_density_matrices",
+    "display_bloch_spheres_and_correlations",
     "get_qctrl_style",
     "plot_controls",
     "plot_discriminator",
@@ -58,4 +57,4 @@ __all__ = [
     "plot_xdata",
 ]
 
-__version__ = "2.4.3"
+__version__ = "2.6.0"
