@@ -1,3 +1,15 @@
+# Copyright 2021 Q-CTRL Pty Ltd & Q-CTRL Inc. All rights reserved.
+#
+# Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
+# copying or use of this file, via any medium, is strictly prohibited.
+# Proprietary and confidential. You may not use this file except in compliance
+# with the License. You may obtain a copy of the License at
+#
+#     https://q-ctrl.com/terms
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS. See the
+# License for the specific language.
 """
 Functions for plotting discriminators.
 """
@@ -6,6 +18,8 @@ from typing import (
     Any,
     Dict,
     List,
+    Optional,
+    Tuple,
 )
 
 import numpy as np
@@ -21,43 +35,45 @@ def plot_discriminator(
     show_boundary: bool = False,
     show_fitting_data: bool = True,
     flag_misclassified: bool = False,
-    qubits_to_plot: List[int] = None,
+    qubits_to_plot: Optional[List[int]] = None,
     title: bool = True,
-):
+) -> Tuple:
     """
     Creates plots for a specified discriminator.
 
     Parameters
     ----------
-    discriminator : Union[List[IQDiscriminationFitter], IQDiscriminationFitter]
-         A discriminator or list of discriminators
-    axs : np.ndarray
-        matplotlib axes (default: {None})
-    show_boundary : bool
-        Show decision boundary (default: {False})
-    show_fitting_data : bool
-        Show/plot data used to fit discriminator (default: {True})
-    flag_misclassified : bool
-        Plot misclassified points (default: {False})
-    qubits_to_plot : List[int]
-        Which qubits to include (default: {None})
-    title : bool
-        Include title in plots (default: {True})
+    discriminator : Union[IQDiscriminationFitter, List[IQDiscriminationFitter]]
+         A discriminator or list of discriminators.
+    axs : np.ndarray, optional
+        Axes from a Matplotlib figure. Defaults to ``None``.
+    show_boundary : bool, optional
+        Whether to show decision boundary. Defaults to ``False``.
+    show_fitting_data : bool, optional
+        Whether to show data used to fit the discriminator. Defaults to
+        ``True``.
+    flag_misclassified : bool, optional
+        Whether to plot misclassified points. Defaults to ``False``.
+    qubits_to_plot : List[int], optional
+        Which qubits to include. Defaults to ``None``.
+    title : bool, optional
+        Whether to include title in plots. Defaults to ``True``.
 
     Returns
     -------
-    Union[List[axes], axes], figure)
-        the axes object used for the plot as well as the figure handle.
-        The figure handle returned is None iff axs is passed.
+    Tuple[Union[List[axes], axes], figure]
+        A tuple containing the axes object used for the plot as well as the
+        figure handle. The figure handle returned is ``None`` if and only
+        if `axs` is passed.
 
     Raises
     ------
     ValueError
-        If qubit is not in the qubit_mask
+        If qubit is not in the `qubit_mask`.
     ValueError
-        If not enough axes instances are passed. Requires 1 per qubit.
+        If you don't pass enough axes instances. Requires 1 per qubit.
     ValueError
-        If show_boundary is True for multi-qubit cases.
+        If `show_boundary` is ``True`` for multi-qubit cases.
     ValueError
         If expected state labels cannot be cast to floats.
     """
@@ -170,7 +186,7 @@ def plot_discriminator(
 @qctrl_style()
 def plot_xdata(discriminator: Any, axs: np.ndarray, results: Any):
     """
-    Add the relevant IQ data from the Result, or list of results, to
+    Adds the relevant IQ data from the Result, or list of results, to
     the given axes as a scatter plot.
 
     Parameters
@@ -179,10 +195,8 @@ def plot_xdata(discriminator: Any, axs: np.ndarray, results: Any):
         An arbitrary Q-CTRL discriminator that follows the defined interface
         and has `fit` and `discriminate` methods.
     axs : Union[np.ndarray, axes]
-        The axes to use for the plot. If
-        the number of axis instances provided is less than the number
-        of qubits then only the data for the first len(axs) qubits will
-        be plotted.
+        The axes to use for the plot. You must provide at least as many
+        axes as the number of qubits.
     results : Union[Result, List[Result]]
         The discriminators get_xdata will be used to retrieve the
         x data from the Result or list of Results.
@@ -190,7 +204,7 @@ def plot_xdata(discriminator: Any, axs: np.ndarray, results: Any):
     Raises
     ------
     ValueError
-        Not enought axes are provided. Requires one per qubit
+        If you don't provide enough axes. Requires one per qubit
         discriminated.
     """
     if not isinstance(axs, np.ndarray):
