@@ -57,6 +57,8 @@ def get_qctrl_style() -> Dict[str, Any]:
     style["axes.labelsize"] = 11
     style["axes.labelcolor"] = TEXT_COLOR
 
+    style["figure.facecolor"] = "white"
+
     style["legend.edgecolor"] = BORDER_COLOR
 
     style["lines.color"] = BORDER_COLOR
@@ -64,17 +66,14 @@ def get_qctrl_style() -> Dict[str, Any]:
     style["axes.prop_cycle"] = cycler(
         color=[
             "#680CE9",
-            "#FB00A5",
-            "#FF005B",
-            "#FF8B11",
-            "#FFD900",
-            "#BCDA38",
-            "#7FD361",
-            "#45C783",
-            "#00B89C",
-            "#00A8C4",
-            "#0092F8",
-            "#006FFF",
+            "#EB6467",
+            "#57CDC8",
+            "#E583F7",
+            "#CECF58",
+            "#64A0EB",
+            "#E98C55",
+            "#EB64B6",
+            "#57CD71",
         ]
     )
 
